"use strict";

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.string.split.js");

require("core-js/modules/es.object.assign.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

var _client = require("@apollo/client");

var _error = require("@apollo/client/link/error");

var _ws = require("@apollo/client/link/ws");

var _utilities = require("@apollo/client/utilities");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

var _reactRouterDom = require("react-router-dom");

var _ChatState = _interopRequireDefault(require("../../context/chat/ChatState"));

var _chatListOptions = require("../../sampleData/chatListOptions");

var _usePreviousState = _interopRequireDefault(require("../../_helpers/usePreviousState"));

var _ChatListShell = _interopRequireDefault(require("../ChatListShell/ChatListShell"));

var _ConversationShell = _interopRequireDefault(require("../ConversationShell/ConversationShell"));

var _ChatShellModule = _interopRequireDefault(require("./ChatShell.module.scss"));

const _excluded = ["connectionUri", "subscriptionUri", "chatApiUrl", "query", "resetChatList", "backendApiUrl"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const ChatShell = _ref => {
  let {
    connectionUri,
    subscriptionUri,
    chatApiUrl,
    query,
    resetChatList,
    backendApiUrl
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  const {
    username
  } = (0, _reactRouterDom.useParams)();
  const navigate = (0, _reactRouterDom.useNavigate)();

  const [queryMessagesBody, setQueryMessagesBody] = _react.default.useState(null);

  const [isSearchedMessageSelected, setSelectedMessageStatus] = _react.default.useState(false);

  const prevQueryRef = (0, _usePreviousState.default)(query);
  const [optionalParams] = (0, _reactRouterDom.useSearchParams)();
  const profileName = optionalParams.get('profileName');
  const threadId = optionalParams.get('threadId');
  const messageId = optionalParams.get('messageId');

  _react.default.useEffect(() => {
    if ((query === null || query === void 0 ? void 0 : query.parameter.length) === 0 || (prevQueryRef === null || prevQueryRef === void 0 ? void 0 : prevQueryRef.parameter) !== query.parameter) {
      setQueryMessagesBody(null);
    }
    /**
     * This code is used in case when user tries to search a query when he is seeing the messages of a particular profile.
     * Then the route at that situation is like /chat/0X234d. In that scenerio, we want to show him search results rather the
     * current profile chats
     */


    if ((query === null || query === void 0 ? void 0 : query.parameter.length) !== 0 && username) {
      navigate('/chat');
    }
  }, [query, prevQueryRef]);
  /**
   * This useEffect run when user open a particular search entry or close that entry
   * This will also handle the browser native back functionality
   */


  _react.default.useEffect(() => {
    if (threadId !== null && messageId !== null && (query === null || query === void 0 ? void 0 : query.parameter.length) !== 0) {
      setQueryMessagesBody({
        threadId,
        messageId,
        profileName
      });
      setSelectedMessageStatus(true);
    } else {
      navigate('/chat');
      setSelectedMessageStatus(false);
    }
  }, [threadId, messageId]);

  const errorLink = (0, _error.onError)(_ref2 => {
    let {
      graphqlErrors
    } = _ref2;

    if (graphqlErrors) {
      graphqlErrors.map(_ref3 => {
        let {
          message
        } = _ref3;
        return alert("Graphql error ".concat(message));
      });
    }
  });
  const httpLink = (0, _client.from)([errorLink, new _client.HttpLink({
    uri: connectionUri
  })]);
  const wsLink = process.browser ? new _ws.WebSocketLink({
    uri: subscriptionUri,
    options: {
      reconnect: true,
      lazy: true
    }
  }) : null;
  const splitLink = process.browser ? (0, _client.split)(_ref4 => {
    let {
      query
    } = _ref4;
    const definition = (0, _utilities.getMainDefinition)(query);
    return definition.kind === "OperationDefinition" && definition.operation === "subscription";
  }, wsLink, httpLink) : httpLink;
  const client = new _client.ApolloClient({
    cache: new _client.InMemoryCache(),
    link: splitLink
  });

  const [isUsername, setIsUsername] = _react.default.useState(false);

  const handleSetIsUsername = val => {
    if (val) {
      setIsUsername(true);
    } else {
      setIsUsername(false);
    }
  };

  const handlesetQueryMessagesBody = val => {
    setQueryMessagesBody(val);
  };

  return /*#__PURE__*/_react.default.createElement(_ChatState.default, {
    backendApiUrl: backendApiUrl
  }, /*#__PURE__*/_react.default.createElement(_client.ApolloProvider, {
    client: client
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _ChatShellModule.default.ChatShell
  }, /*#__PURE__*/_react.default.createElement(_ChatListShell.default, _extends({
    options: _chatListOptions.chatListOptions,
    isUsername: isUsername,
    query: query,
    resetChatList: resetChatList,
    isSearchedMessageSelected: isSearchedMessageSelected,
    setQueryMessagesBody: handlesetQueryMessagesBody
  }, rest)), /*#__PURE__*/_react.default.createElement(_ConversationShell.default, {
    query: query,
    chatApiUrl: chatApiUrl,
    backendApiUrl: backendApiUrl,
    queryMessagesBody: queryMessagesBody,
    handleSetIsUsername: handleSetIsUsername
  }))));
};

ChatShell.propTypes = {
  query: _propTypes.default.shape({
    parameter: _propTypes.default.string
  }),
  resetChatList: _propTypes.default.func
};
ChatShell.defaultProps = {
  query: {
    parameter: "message"
  },
  resetChatList: () => console.log("This function will reset the ChatListSheel to its default state"),
  backendApiUrl: "https://backend.dgraph.smarter.codes"
};
var _default = ChatShell;
exports.default = _default;