"use strict";

require("core-js/modules/es.promise.js");

var _testing = require("@apollo/client/testing");

var _react = require("@testing-library/react");

var _react2 = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _reactRouterDom = _interopRequireDefault(require("react-router-dom"));

var _ChatContext = _interopRequireDefault(require("../../context/chat/ChatContext"));

var _Queries = require("../../GraphQL/Queries");

var _ConversationShell = _interopRequireDefault(require("./ConversationShell"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const mockedUsedNavigate = jest.fn();
jest.mock("react-router-dom", () => _objectSpread(_objectSpread({}, jest.requireActual("react-router-dom")), {}, {
  useNavigate: () => mockedUsedNavigate,
  useParams: () => ({
    username: "X2034S"
  })
}));
const mocks = [];
const value = {
  storeNewMessages: jest.fn()
};

const comp = /*#__PURE__*/_react2.default.createElement(_ChatContext.default.Provider, {
  value: value
}, /*#__PURE__*/_react2.default.createElement(_testing.MockedProvider, {
  mocks: mocks
}, /*#__PURE__*/_react2.default.createElement(_ConversationShell.default, {
  handleSetIsUsername: () => {}
})), " ");

describe("rendring of components", () => {
  it("It should mount", () => {
    const div = document.createElement("div");

    _reactDom.default.render(comp, div);

    _reactDom.default.unmountComponentAtNode(div);
  });
});
describe("data from query", () => {
  it("It should mount with data", async () => {
    jest.spyOn(_reactRouterDom.default, "useParams").mockReturnValue({
      username: "0x2725"
    });
    const loadusersmock = {
      request: {
        query: _Queries.LOAD_MESSAGES,
        variables: {
          leadId: "0x2725"
        }
      },
      result: {
        data: {
          getHC_Lead: {
            username: "Sahil Thakur",
            threads: [{
              id: "0x2724",
              messages: [{
                from: "whatsapp:+918988413260",
                to: "whatsapp:+14155238886",
                timestamp: "1637295513344",
                body: "Sending first message",
                __typename: "Message"
              }, {
                from: "whatsapp:+918988413260",
                to: "whatsapp:+14155238886",
                timestamp: "1637295528041",
                body: "Second message from me",
                __typename: "Message"
              }],
              __typename: "Thread"
            }],
            __typename: "HC_Lead"
          }
        }
      }
    };

    let el = /*#__PURE__*/_react2.default.createElement(_ChatContext.default.Provider, {
      value: value
    }, /*#__PURE__*/_react2.default.createElement(_testing.MockedProvider, {
      mocks: [loadusersmock]
    }, /*#__PURE__*/_react2.default.createElement(_ConversationShell.default, {
      selectedId: "0x2725",
      handleSetIsUsername: () => {}
    })), " ");

    await new Promise(resolve => setTimeout(resolve, 1000)); // wait for response

    const {
      container,
      getAllByText
    } = (0, _react.render)(el);
    await (0, _react.waitFor)(() => expect(getAllByText("Sahil Thakur")[0]).toBeInTheDocument());
  });
});
describe("tabs should render", () => {
  it.skip("Files option should render if there is a selected id", async () => {
    jest.spyOn(_reactRouterDom.default, "useParams").mockReturnValue({
      username: "X2012"
    });
    const {
      container,
      getByText
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_ChatContext.default.Provider, {
      value: value
    }, /*#__PURE__*/_react2.default.createElement(_testing.MockedProvider, {
      mocks: mocks
    }, /*#__PURE__*/_react2.default.createElement(_ConversationShell.default, {
      selectedId: "x",
      handleSetIsUsername: () => {}
    })), " "));
    await (0, _react.waitFor)(() => expect(getByText("Files")).toBeInTheDocument());
  });
});
describe("rendering of items when no chat is selected", () => {
  it("should show select contact if there is NO selected id", async () => {
    jest.spyOn(_reactRouterDom.default, "useParams").mockReturnValue({
      username: null
    });
    const {
      container,
      getByTestId
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_ChatContext.default.Provider, {
      value: value
    }, /*#__PURE__*/_react2.default.createElement(_testing.MockedProvider, {
      mocks: mocks
    }, /*#__PURE__*/_react2.default.createElement(_ConversationShell.default, {
      handleSetIsUsername: () => {}
    })), " "));
    await (0, _react.waitFor)(() => expect(getByTestId("selectcontact")).toBeInTheDocument());
  });
});